@@ -1,7 +1,7 @@
 package MsgPack::Encoder;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Encode a structure into a MessagePack binary string
-$MsgPack::Encoder::VERSION = '0.1.2';
+$MsgPack::Encoder::VERSION = '1.0.0';
 
 use strict;
 use warnings;
@@ -135,13 +135,13 @@ my $Str32 = Type::Tiny->new(
 my $Str16 = Type::Tiny->new(
     parent => $Str32,
     name => 'Str16',
-    constaints => sub { length $_ < 2**16 }
+    constraint => sub { length $_ < 2**16 }
 );
 
 my $Str8 = Type::Tiny->new(
     parent => $Str16,
     name => 'Str8',
-    constaints => sub { length $_ < 2**8 }
+    constraint => sub { length $_ < 2**8 }
 );
 
 my $FixStr = Type::Tiny->new(
@@ -164,7 +164,7 @@ my $Array16 = Type::Tiny->new(
 my $FixArray = Type::Tiny->new(
     parent => ArrayRef,
     name => 'FixArray',
-    constraint => sub { @$_ < 31 },
+    constraint => sub { @$_ < 16 },
 );
 
 my $Nil = Type::Tiny->new(
@@ -489,7 +489,7 @@ MsgPack::Encoder - Encode a structure into a MessagePack binary string
 
 =head1 VERSION
 
-version 0.1.2
+version 1.0.0
 
 =head1 SYNOPSIS
 
