@@ -1,19 +1,21 @@
 package MsgPack::RPC;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: MessagePack RPC client
-$MsgPack::RPC::VERSION = '0.1.2';
+$MsgPack::RPC::VERSION = '1.0.0';
 
 use strict;
 use warnings;
 
 use Moose;
+
 use IO::Socket::INET;
 use IO::Socket::UNIX;
 use MsgPack::Decoder;
 use MsgPack::Encoder;
 use MsgPack::RPC::Message;
 use MsgPack::RPC::Message::Request;
-use Future;
+
+use Promises qw/ deferred /;
 
 use experimental 'signatures';
 
@@ -104,13 +106,13 @@ has "response_callbacks" => (
 
 sub add_response_callback {
     my( $self, $id ) = @_;
-    my $future = Future->new;
+    my $deferred = deferred;
     $self->response_callbacks->{$id} = {
         timestamp => time,
-        future => $future,
+        deferred => $deferred,
     };
 
-    $future;
+    $deferred;
 }
 
 sub request($self,$method,$args=[],$id=++$MsgPack::RPC::MSG_ID) {
@@ -166,10 +168,10 @@ sub loop {
             if ( $next->[0] == 1 ) {
                 $self->log_debug( [ "it's a response for %d", $next->[1] ] );
                 if( my $callback =  $self->response_callbacks->{$next->[1]} ) {
-                    my $f = $callback->{future};
+                    my $f = $callback->{deferred};
                     $next->[2] 
-                        ? $f->fail($next->[2])
-                        : $f->done($next->[3])
+                        ? $f->reject($next->[2])
+                        : $f->resolve($next->[3])
                         ;
                 }
             }
@@ -187,6 +189,9 @@ sub loop {
                 elsif( eval { $until->isa('Future') } ) {
                     return if $until->is_done;
                 }
+                elsif( eval { $until->can('is_in_progress') } ) {
+                    return unless $until->is_in_progress;
+                }
                 else {
                     return if $until and not --$until;
                 }
@@ -211,7 +216,7 @@ MsgPack::RPC - MessagePack RPC client
 
 =head1 VERSION
 
-version 0.1.2
+version 1.0.0
 
 =head1 SYNOPSIS
 
